summaryrefslogtreecommitdiffstats
path: root/lib/kformula/symbolelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/symbolelement.h')
-rw-r--r--lib/kformula/symbolelement.h74
1 files changed, 37 insertions, 37 deletions
diff --git a/lib/kformula/symbolelement.h b/lib/kformula/symbolelement.h
index cb908034..799703a6 100644
--- a/lib/kformula/symbolelement.h
+++ b/lib/kformula/symbolelement.h
@@ -36,7 +36,7 @@ public:
//enum { contentPos, upperPos, lowerPos };
- SymbolElement(SymbolType type = EmptyBracket, BasicElement* parent = 0);
+ SymbolElement(SymbolType type = EmptyBracket, BasicElement* tqparent = 0);
~SymbolElement();
SymbolElement( const SymbolElement& );
@@ -54,7 +54,7 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
// drawing
//
@@ -65,7 +65,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -73,19 +73,19 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
@@ -125,7 +125,7 @@ public:
*/
virtual void moveDown(FormulaCursor* cursor, BasicElement* from);
- // children
+ // tqchildren
/**
* Removes the child. If this was the main child this element might
@@ -139,14 +139,14 @@ public:
// main child
//
- // If an element has children one has to become the main one.
+ // If an element has tqchildren one has to become the main one.
virtual SequenceElement* getMainChild() { return content; }
//virtual void setMainChild(SequenceElement*);
/**
- * Inserts all new children at the cursor position. Places the
+ * Inserts all new tqchildren at the cursor position. Places the
* cursor according to the direction.
*
* You only can insert one index at a time. So the list must contain
@@ -155,11 +155,11 @@ public:
*
* The list will be emptied but stays the property of the caller.
*/
- virtual void insert(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void insert(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
- * Removes all selected children and returns them. Places the
- * cursor to where the children have been.
+ * Removes all selected tqchildren and returns them. Places the
+ * cursor to where the tqchildren have been.
*
* The cursor has to be inside one of our indexes which is supposed
* to be empty. The index will be removed and the cursor will
@@ -168,7 +168,7 @@ public:
*
* The ownership of the list is passed to the caller.
*/
- virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
* Moves the cursor to a normal place where new elements
@@ -216,18 +216,18 @@ public:
ElementIndexPtr getIndex( int position );
// Save&load
- //virtual QDomElement getElementDom(QDomDocument *doc);
- //virtual bool buildFromDom(QDomElement *elem);
+ //virtual TQDomElement getElementDom(TQDomDocument *doc);
+ //virtual bool buildFromDom(TQDomElement *elem);
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
- virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false ) const ;
+ virtual void writeMathML( TQDomDocument& doc, TQDomNode& tqparent, bool oasisFormat = false ) const ;
protected:
@@ -236,25 +236,25 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "SYMBOL"; }
+ virtual TQString getTagName() const { return "SYMBOL"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
private:
@@ -263,34 +263,34 @@ private:
*/
class SymbolElementIndex : public ElementIndex {
public:
- SymbolElementIndex(SymbolElement* p) : parent(p) {}
- virtual SymbolElement* getElement() { return parent; }
+ SymbolElementIndex(SymbolElement* p) : tqparent(p) {}
+ virtual SymbolElement* getElement() { return tqparent; }
protected:
- SymbolElement* parent;
+ SymbolElement* tqparent;
};
// We have a (very simple) type for every index.
class UpperIndex : public SymbolElementIndex {
public:
- UpperIndex(SymbolElement* parent) : SymbolElementIndex(parent) {}
+ UpperIndex(SymbolElement* tqparent) : SymbolElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToUpper(cursor, direction); }
+ { tqparent->moveToUpper(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToUpper(cursor); }
+ { tqparent->setToUpper(cursor); }
virtual bool hasIndex() const
- { return parent->hasUpper(); }
+ { return tqparent->hasUpper(); }
};
class LowerIndex : public SymbolElementIndex {
public:
- LowerIndex(SymbolElement* parent) : SymbolElementIndex(parent) {}
+ LowerIndex(SymbolElement* tqparent) : SymbolElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToLower(cursor, direction); }
+ { tqparent->moveToLower(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToLower(cursor); }
+ { tqparent->setToLower(cursor); }
virtual bool hasIndex() const
- { return parent->hasLower(); }
+ { return tqparent->hasLower(); }
};
@@ -73,19 +73,19 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/